==> moengage_flutter-5.1.1.tar.gz: lib/push_payload_mapper.dart <==
import 'dart:convert';

import 'package:moengage_flutter/constants.dart';
import 'package:moengage_flutter/model/platforms.dart';
import 'package:moengage_flutter/model/push/moe_push_service.dart';
import 'package:moengage_flutter/model/push/push_campaign.dart';
import 'package:moengage_flutter/model/push/push_campaign_data.dart';
import 'package:moengage_flutter/model/push/push_token_data.dart';
import 'package:moengage_flutter/utils.dart';

class PushPayloadMapper {
  String _tag = "${TAG}PushPayloadMapper";

  PushTokenData? pushTokenFromJson(dynamic methodCallArgs) {
    try {
      Map<String, dynamic> tokenData = json.decode(methodCallArgs);
      return PushTokenData(
          PlatformsExtension.fromString(tokenData[keyPlatform]),
          tokenData[keyPushToken],
          MoEPushServiceExtention.fromString(tokenData[keyPushService]));
    } catch (exception) {
      print("$_tag Error: pushTokenFromJson() : ${exception.toString()}");
    }
    return null;
  }

  PushCampaignData? pushCampaignFromJson(dynamic methodCallArgs) {
    try {
      print("$_tag pushCampaignFromJson() : $methodCallArgs");
      Map<String, dynamic> pushCampaignPayload = json.decode(methodCallArgs);
      Map<String, dynamic> campaignData = pushCampaignPayload[keyData];
      return PushCampaignData(
          PlatformsExtension.fromString(campaignData[keyPlatform]),
          accountMetaFromMap(pushCampaignPayload[keyAccountMeta]),
          PushCampaign(
              campaignData.containsKey(keyIsDefaultAction)
                  ? campaignData[keyIsDefaultAction]
                  : false,
              campaignData.containsKey(keyClickedAction)
                  ? campaignData[keyClickedAction]
                  : new Map(),
              campaignData.containsKey(keyPayload)
                  ? campaignData[keyPayload]
                  : new Map()));
    } catch (e) {
      print("$_tag Error: pushCampaignFromJson() : $e");
    }
    return null;
  }
}

==> moengage_flutter-5.3.0.tar.gz: lib/push_payload_mapper.dart <==
import 'dart:convert';

import 'package:moengage_flutter/constants.dart';
import 'package:moengage_flutter/internal/logger.dart';
import 'package:moengage_flutter/model/platforms.dart';
import 'package:moengage_flutter/model/push/moe_push_service.dart';
import 'package:moengage_flutter/model/push/push_campaign.dart';
import 'package:moengage_flutter/model/push/push_campaign_data.dart';
import 'package:moengage_flutter/model/push/push_token_data.dart';
import 'package:moengage_flutter/utils.dart';

class PushPayloadMapper {
  final _tag = "${TAG}PushPayloadMapper";

  PushTokenData? pushTokenFromJson(dynamic methodCallArgs) {
    try {
      Map<String, dynamic> tokenData = json.decode(methodCallArgs);
      return PushTokenData(
          PlatformsExtension.fromString(tokenData[keyPlatform]),
          tokenData[keyPushToken],
          MoEPushServiceExtention.fromString(tokenData[keyPushService]));
    } catch (exception, stackTrace) {
      Logger.e("$_tag Error: pushTokenFromJson() : ",
          stackTrace: stackTrace, error: exception);
    }
    return null;
  }

  PushCampaignData? pushCampaignFromJson(dynamic methodCallArgs) {
    try {
      Logger.v("$_tag pushCampaignFromJson() : $methodCallArgs");
      Map<String, dynamic> pushCampaignPayload = json.decode(methodCallArgs);
      Map<String, dynamic> campaignData = pushCampaignPayload[keyData];
      return PushCampaignData(
          PlatformsExtension.fromString(campaignData[keyPlatform]),
          accountMetaFromMap(pushCampaignPayload[keyAccountMeta]),
          PushCampaign(
              campaignData.containsKey(keyIsDefaultAction)
                  ? campaignData[keyIsDefaultAction]
                  : false,
              campaignData.containsKey(keyClickedAction)
                  ? campaignData[keyClickedAction]
                  : new Map(),
              campaignData.containsKey(keyPayload)
                  ? campaignData[keyPayload]
                  : new Map()));
    } catch (e, stackTrace) {
      Logger.e("$_tag Error: pushTokenFromJson() : ",
          stackTrace: stackTrace, error: e);
    }
    return null;
  }
}
